@@ -18,15 +18,20 @@
 #'  will return only the clustered heatmap.
 #' @param domains.column Character. A vector of cluster names for the clustered heatmap.
 #' Used only when type is 'plot'.
+#' @param highlight_labels Vector. Numeric vector specifying problematic states and their neighboring states to be highlighted in the dendrogram. 
+#' This argument is intended for internal use only. The default value is NULL.
+#' @param only_dendro Logical. A logical string specifies whether to generate only the dendrogram or to include the results as well.
+#' This argument is intended for internal use only. The default value is FALSE.
 #' @return A list object that contains the hierarchical clustering results.
 #' \item{[[1]] }{Summary of k suggested by all indices with plots} 
-#' \item{[[2]] }{A dendogram plot with the selected number of clusters} 
+#' \item{[[2]] }{A dendrogram plot with the selected number of clusters} 
 #' \item{[[3]] }{A 2D Cluster HVT Plotly visualization that colors cells according to clusters derived from AGNES clustering results. 
 #' It is interactive, allowing users to view cell contents by hovering over them}
 #' @author Vishwavani <vishwavani@@mu-sigma.com>
 #' @keywords Clustering_Analysis
 #' @include clusterPlot.R
 #' @importFrom utils data head tail
+#' @importFrom stats as.dendrogram median 
 #' @examples 
 #'data("EuStockMarkets")
 #'dataset <- data.frame(t = as.numeric(time(EuStockMarkets)),
@@ -55,7 +60,7 @@ clustHVT <- function(data, trainHVT_results, scoreHVT_results, clustering_method
                                  "ratkowsky", "ball", "hubert", "dindex", "ptbiserial", 
                                  "gap", "frey", "mcclain", "gamma", "gplus", "tau", 
                                  "dunn", "sdindex", "sdbw"), 
-                     clusters_k = "champion", type = "default", domains.column = NULL) {
+                     clusters_k = "champion", type = "default", domains.column = NULL, highlight_labels = NULL, only_dendro = FALSE) {
   requireNamespace('NbClust')
   
   if (type == "plot"){
@@ -156,42 +161,89 @@ clustHVT <- function(data, trainHVT_results, scoreHVT_results, clustering_method
     stop(sprintf("Clustering error: k=%d out of range [1..%d]", no_of_clusters, n_items))
   }
   
+  #########cell_id#####
+  hvt_list <- trainHVT_results
+  hvt_res1 <- hvt_list[[2]][[1]]$`1`
+  hvt_res2 <- hvt_list[[3]]$summary$Cell.ID
+  a <- seq_along(hvt_res1)
+  b <- a[hvt_res2]
+  b <- as.vector(b)
+  hvt_res2 <- stats::na.omit(b)
+  hclust_data_1 <- hclust_data
+  rownames(hclust_data_1)<- hvt_res2
+
+#browser()  
+  
   # Perform hierarchical clustering
-  hc <- stats::hclust(stats::dist(as.matrix(hclust_data)), method = clustering_method)
+  hc <- stats::hclust(stats::dist(as.matrix(hclust_data_1)), method = clustering_method)
   clusters <- stats::cutree(hc, k = no_of_clusters)
   
-#browser()  
-  # Replace the existing plot_dendrogram function with this:
-  plot_dendrogram <- function(hc_1, no_of_clusters_1) {
-    function() {
-      plot(hc_1, xlab = "Clusters", ylab = "Distance", sub ="")
-      stats::rect.hclust(hc_1, k = no_of_clusters_1, border = grDevices::rainbow(no_of_clusters_1))
+# Replace the existing plot_dendrogram function with this:
+  # plot_dendrogram <- function(hc_1, no_of_clusters_1) {
+  #   function() {
+  #     plot(hc_1, xlab = "Clusters", ylab = "Distance", sub ="")
+  #     stats::rect.hclust(hc_1, k = no_of_clusters_1, border = grDevices::rainbow(no_of_clusters_1))
+  #   }
+  # }
+  
+  if(only_dendro){
+    plot_dendrogram <- function(hc_1, no_of_clusters_1, highlight_labels = NULL) {
+      
+      function() {
+        dend <- as.dendrogram(hc_1)
+        
+        if (!is.null(highlight_labels)) {
+          labels_colors <- ifelse(labels(dend) %in% highlight_labels, "red", "black")
+          dend <- dendextend::set(dend, "labels_col", labels_colors)
+        }
+        dend <- dendextend::set(dend, "labels_cex", 1)
+        plot(dend, ylab = "Distance", xlab = "Clusters", leaflab = "perpendicular")
+        dendextend::rect.dendrogram(dend, k = no_of_clusters_1, 
+                                    border = grDevices::rainbow(no_of_clusters_1))
+      }
     }
-  }
-  
-  a <- plot_dendrogram(hc_1 = hc, no_of_clusters_1 = no_of_clusters)
-
     
-#browser()  
-  
-  # Prepare data for clusterPlotly
-  cluster_data <- scoreHVT_results$centroidData %>% 
-    dplyr::select("Cell.ID", "names.column") %>%
-    mutate(clusters =  clusters)
-  
-  #cluster_data <- cluster_data[order(cluster_data$Cell.ID), ]
-  
-  
-  b <- clusterPlot(dataset= cluster_data, hvt.results  = trainHVT_results, domains.column = "clusters" )
-  
-  output_list <- list(
-    hc = hc,
-    clusters = clusters,
-    cluster_data =cluster_data,
-    dendogram = a,
-    clusterplot = b
-  )
-  
-  return(output_list)
-}
+    
+    a <- plot_dendrogram(hc_1 = hc,no_of_clusters_1 = no_of_clusters,highlight_labels = highlight_labels)
+    
+    output_list <- list(dendrogram = a)
+    return(output_list)
+  }else {
+    plot_dendrogram <- function(hc_1, no_of_clusters_1, highlight_labels = NULL) {
+      
+      function() {
+        dend <- as.dendrogram(hc_1)
+        dend <- dendextend::set(dend, "labels_cex", 1)
+        plot(dend, ylab = "Distance", xlab = "Clusters", leaflab = "perpendicular")
+        dendextend::rect.dendrogram(dend, k = no_of_clusters_1, 
+                                    border = grDevices::rainbow(no_of_clusters_1))
+      }
+    }
+    
+    
+    
+    a <- plot_dendrogram(hc_1 = hc,no_of_clusters_1 = no_of_clusters,highlight_labels = highlight_labels)
+    
+    
+    # Prepare data for clusterPlotly
+    cluster_data <- scoreHVT_results$centroidData %>% 
+      dplyr::select("Cell.ID", "names.column") %>%
+      mutate(clusters =  clusters)
+    
+    cluster_data <- cluster_data[order(cluster_data$Cell.ID), ]
+    #browser()  
+    
+    b <- clusterPlot(dataset= cluster_data, hvt.results  = trainHVT_results, domains.column = "clusters" )
+    
+    output_list <- list(
+      hc = hc,
+      clusters = clusters,
+      cluster_data =cluster_data,
+      dendrogram = a,
+      clusterplot = b
+    )
+    
+    return(output_list)
+  }
+  }
 }
\ No newline at end of file
